@@ -23,15 +23,19 @@
 #include <iostream>
 #include <iomanip>
 #include <list>
+#include <sstream>
 #include <fstream>
+#include <optional>
+
+#include <osmscout/db/Database.h>
 
-#include <osmscout/Database.h>
 #include <osmscout/routing/SimpleRoutingService.h>
 #include <osmscout/routing/RoutePostprocessor.h>
 #include <osmscout/routing/DBFileOffset.h>
 #include <osmscout/routing/RouteDescriptionPostprocessor.h>
 
-#include <osmscout/util/CmdLineParsing.h>
+#include <osmscout/cli/CmdLineParsing.h>
+#include <osmscout/util/Bearing.h>
 #include <osmscout/util/Geometry.h>
 #include <osmscout/util/Time.h>
 
@@ -59,21 +63,23 @@
 
 struct Arguments
 {
-  bool                   help=false;
-  std::string            router=osmscout::RoutingService::DEFAULT_FILENAME_BASE;
-  osmscout::Vehicle      vehicle=osmscout::Vehicle::vehicleCar;
-  std::string            gpx;
-  std::string            databaseDirectory;
-  osmscout::GeoCoord     start;
-  osmscout::GeoCoord     target;
-  bool                   debug=false;
-  bool                   dataDebug=false;
-  bool                   routeDebug=false;
-  std::string            routeJson;
+  bool                              help=false;
+  std::string                       router=osmscout::RoutingService::DEFAULT_FILENAME_BASE;
+  osmscout::Vehicle                 vehicle=osmscout::Vehicle::vehicleCar;
+  std::string                       gpx;
+  std::string                       databaseDirectory;
+  osmscout::GeoCoord                start;
+  std::vector<osmscout::GeoCoord>   via;
+  osmscout::GeoCoord                target;
+  std::optional<osmscout::Bearing>  initialBearing;
+  bool                              debug=false;
+  bool                              dataDebug=false;
+  bool                              routeDebug=false;
+  std::string                       routeJson;
 
-  osmscout::Distance     penaltySameType=osmscout::Meters(40);
-  osmscout::Distance     penaltyDifferentType=osmscout::Meters(250);
-  osmscout::HourDuration maxPenalty=std::chrono::seconds(10);
+  osmscout::Distance                penaltySameType=osmscout::Meters(40);
+  osmscout::Distance                penaltyDifferentType=osmscout::Meters(250);
+  osmscout::HourDuration            maxPenalty=std::chrono::seconds(10);
 };
 
 class ConsoleRoutingProgress : public osmscout::RoutingProgress
@@ -604,6 +610,15 @@ struct RouteDescriptionGeneratorCallback : public osmscout::RouteDescriptionPost
     std::cout << "Pass: " << poiAtRouteDescription->GetName()->GetDescription() << std::endl;
   }
 
+  void OnViaAtRoute(const osmscout::RouteDescription::ViaDescriptionRef& viaDescription) override
+  {
+      size_t sectionNumber = viaDescription->GetSectionNumber();
+      if (sectionNumber > 1) {
+        NextLine(lineCount);
+        std::cout << "Etap: " << sectionNumber - 1  << std::endl;
+      }
+  }
+    
   void BeforeNode(const osmscout::RouteDescription::Node& node) override
   {
     lineCount=0;
@@ -739,11 +754,23 @@ int main(int argc, char* argv[])
                       "penalty-max",
                       "Maximum junction penalty, time [s]. Default "s + std::to_string(duration_cast<seconds>(args.maxPenalty).count()));
 
+  argParser.AddOption(osmscout::CmdLineDoubleOption([&args](double value) {
+                        args.initialBearing=osmscout::Bearing::Degrees(value);
+                      }),
+                      "initial-bearing",
+                      "Initial vehicle bearing (degrees, North is 0, East is 90...).");
+
+  argParser.AddOption(osmscout::CmdLineGeoCoordOption([&args](const osmscout::GeoCoord& value) {
+                        args.via.push_back(value);
+                       }),
+                      "via",
+                      "add a via location coordinate");
+    
   argParser.AddPositional(osmscout::CmdLineStringOption([&args](const std::string& value) {
                             args.databaseDirectory=value;
                           }),
                           "DATABASE",
-                          "Directory of the first database to use");
+                          "Directory of the first db to use");
 
   argParser.AddPositional(osmscout::CmdLineGeoCoordOption([&args](const osmscout::GeoCoord& value) {
                             args.start=value;
@@ -779,7 +806,7 @@ int main(int argc, char* argv[])
   osmscout::DatabaseRef       database=std::make_shared<osmscout::Database>(databaseParameter);
 
   if (!database->Open(args.databaseDirectory)) {
-    std::cerr << "Cannot open database" << std::endl;
+    std::cerr << "Cannot open db" << std::endl;
 
     return 1;
   }
@@ -798,7 +825,7 @@ int main(int argc, char* argv[])
                                                                                             args.router);
 
   if (!router->Open()) {
-    std::cerr << "Cannot open routing database" << std::endl;
+    std::cerr << "Cannot open routing db" << std::endl;
 
     return 1;
   }
@@ -853,11 +880,26 @@ int main(int argc, char* argv[])
   if (target.GetObjectFileRef().GetType()==osmscout::refNode) {
     std::cerr << "Cannot find start node for target location!" << std::endl;
   }
-
-  osmscout::RoutingResult result=router->CalculateRoute(*routingProfile,
-                                                        start,
-                                                        target,
-                                                        parameter);
+    
+  osmscout::RoutingResult result;
+    
+  if (args.via.size() > 0) {
+    std::cout << "Using 'CalculateRouteViaCoords' method" << std::endl;
+    args.via.insert(args.via.begin(), args.start);
+    args.via.push_back(args.target);
+    result=router->CalculateRouteViaCoords(*routingProfile,
+                                           args.via,
+                                           osmscout::Kilometers(1),
+                                           parameter);
+    
+  } else {
+    std::cout << "Using 'CalculateRoute' method" << std::endl;
+    result=router->CalculateRoute(*routingProfile,
+                                  start,
+                                  target,
+                                  args.initialBearing,
+                                  parameter);
+  }
 
   if (!result.Success()) {
     std::cerr << "There was an error while calculating the route!" << std::endl;
@@ -961,6 +1003,10 @@ int main(int argc, char* argv[])
   std::vector<osmscout::RoutingProfileRef> profiles{routingProfile};
   std::vector<osmscout::DatabaseRef>       databases{database};
 
+  // SectionsPostprocessor needs the section lenghts computed in the routing when there are some via points
+  // between start and end
+  postprocessors.push_back(std::make_shared<osmscout::RoutePostprocessor::SectionsPostprocessor>(result.GetSectionLenghts()));
+
   if (!postprocessor.PostprocessRouteDescription(*routeDescriptionResult.GetDescription(),
                                                  profiles,
                                                  databases,
