@@ -9,9 +9,9 @@ using namespace osmscout;
 TEST_CASE("Angle variance with low angle")
 {
   LabelPath path;
-  path.AddPoint(0, 0);
-  path.AddPoint(10, 0);
-  path.AddPoint(20, 4);
+  path.AddPoint(osmscout::Vertex2D(0.0, 0.0));
+  path.AddPoint(osmscout::Vertex2D(10.0, 0.0));
+  path.AddPoint(osmscout::Vertex2D(20.0, 4.0));
 
   REQUIRE(path.TestAngleVariance(0, 20, DegToRad(45)));
   REQUIRE_FALSE(path.TestAngleVariance(0, 20, DegToRad(10)));
@@ -20,9 +20,9 @@ TEST_CASE("Angle variance with low angle")
 TEST_CASE("Angle variance with low angle 2")
 {
   LabelPath path;
-  path.AddPoint(10, 0);
-  path.AddPoint(0, 0);
-  path.AddPoint(-10, 4);
+  path.AddPoint(osmscout::Vertex2D(10.0, 0.0));
+  path.AddPoint(osmscout::Vertex2D(0.0, 0.0));
+  path.AddPoint(osmscout::Vertex2D(-10.0, 4.0));
 
   REQUIRE(path.TestAngleVariance(0, 20, DegToRad(25)));
   REQUIRE_FALSE(path.TestAngleVariance(0, 20, DegToRad(10)));
@@ -31,9 +31,9 @@ TEST_CASE("Angle variance with low angle 2")
 TEST_CASE("Angle variance with low angle 3")
 {
   LabelPath path;
-  path.AddPoint(-10, 0);
-  path.AddPoint(0, 0);
-  path.AddPoint(10, 4);
+  path.AddPoint(osmscout::Vertex2D(-10.0, 0.0));
+  path.AddPoint(osmscout::Vertex2D(0.0, 0.0));
+  path.AddPoint(osmscout::Vertex2D(10.0, 4.0));
 
   REQUIRE(path.TestAngleVariance(0, 20, DegToRad(25)));
   REQUIRE_FALSE(path.TestAngleVariance(0, 20, DegToRad(10)));
@@ -42,8 +42,8 @@ TEST_CASE("Angle variance with low angle 3")
 TEST_CASE("Angle variance with high angle")
 {
   LabelPath path;
-  path.AddPoint(10,0);
-  path.AddPoint(0,0);
-  path.AddPoint(10,5);
+  path.AddPoint(osmscout::Vertex2D(10.0,0.0));
+  path.AddPoint(osmscout::Vertex2D(0.0,0.0));
+  path.AddPoint(osmscout::Vertex2D(10.0,5.0));
   REQUIRE_FALSE(path.TestAngleVariance(0, 20, DegToRad(45)));
 }
