@@ -42,7 +42,7 @@
 
 #include <osmscout/system/Assert.h>
 
-#include <osmscout/util/Logger.h>
+#include <osmscout/log/Logger.h>
 #include <osmscout/util/String.h>
 
 #include <osmscoutmap/oss/Scanner.h>
@@ -269,7 +269,8 @@ void Parser::IMPORT() {
 		
 		bool success=config.Load(moduleFileName,
 		                        colorPostprocessor,
-		                        true);
+		                        true,
+		                        errors->log);
 		
 		if (!success) {
 		 std::string e="Cannot load module '"+moduleFileName+"'";
@@ -2455,7 +2456,8 @@ void Parser::Parse()
 Parser::Parser(Scanner *scanner,
                const std::string& filename,
                StyleConfig& config,
-               osmscout::ColorPostprocessor colorPostprocessor)
+               osmscout::ColorPostprocessor colorPostprocessor,
+               const Log &log)
  : filename(filename),
    config(config)
 {
@@ -2466,7 +2468,7 @@ Parser::Parser(Scanner *scanner,
   minErrDist = 2;
   errDist = minErrDist;
   this->scanner = scanner;
-  errors = new Errors();
+  errors = new Errors(log);
   this->colorPostprocessor=colorPostprocessor;
 }
 
@@ -2505,8 +2507,8 @@ osmscout::Color Parser::PostprocessColor(const osmscout::Color& color) const
   }
 }
 
-Errors::Errors()
- : hasErrors(false)
+Errors::Errors(const Log &log)
+ : log(log)
 {
   // no code
 }
